#! /bin/sh
#********************************************
#*                                          * 
#*   LICENSED MATERIALS - PROPERTY OF IBM   *   
#*   "RESTRICTED MATERIALS OF IBM"          *           
#*   5724-M00                               *                
#*   (C) COPYRIGHT IBM CORP. 2005           *     
#*                                          *          
#********************************************
#
# Usage: db2_create_opcons_db.sh <instance_owner> <db_name> <alias_name> <node_name>
#
# Parameters:
#  <instance_owner> - The instance owner used to work with DB2.
#  <db_name>        - The database is created with this name.
#  <alias_name>     - The database alias is created with this name.
#                     OMIT PARAMETER for remote database setup.
#  <node_name>      - The database node is cataloged with this name.
#                     OMIT PARAMETER for remote database setup.
#
# Description of exit codes:
# 0     - Script completed successfully
# 1     - Failed to execute db2start
# 2     - Failed to catalog database node
# 3     - Failed to create the database
# 4..11 - Failed to alter the database
# 12    - Failed to change database setting
# 13    - Failed to catalog database alias
#

INSTANCE_OWNER=$1
DB_NAME=$2

# Check if script is run for remote database.
# Four parameters means local database setup.
if [ $# -eq 4 ] ; then
  ALIAS_NAME=$3
  NODE_NAME=$4
fi


# start db2
su - $INSTANCE_OWNER -c "db2 db2start"
if [ $? -gt 4 ] ; then
  echo "Error in $0: db2start failed"
  exit 1
fi


# Uncatalog database alias and database node only
# in case of local database setup. Ignore uncatalog
# problems.
if [ $# -eq 4 ] ; then
  su - $INSTANCE_OWNER -c "db2 -v UNCATALOG DATABASE $ALIAS_NAME"
  su - $INSTANCE_OWNER -c "db2 -v UNCATALOG NODE $NODE_NAME"
fi


# ignore DROP DATABASE return code
su - $INSTANCE_OWNER -c "db2 -v DROP DATABASE $DB_NAME"

# Catalog database node in case of local database setup.
if [ $# -eq 4 ] ; then
  DB2SERVER=`hostname`
  SVCE=`su - $INSTANCE_OWNER -c "db2 GET DBM CFG" | grep SVCENAME | awk '{print $NF}'`
  su - $INSTANCE_OWNER -c "db2 -v -t CATALOG TCPIP NODE $NODE_NAME REMOTE $DB2SERVER SERVER $SVCE"
  if [ $? -ne 0 ] ; then
    echo "Error in $0: Failed to catalog database node"
    exit 2
  fi
fi


su - $INSTANCE_OWNER -c "db2 -v CREATE DATABASE $DB_NAME USING CODESET UTF-8 TERRITORY us"
if [ $? -ne 0 ] ; then
  echo "Error in $0: Failed to create database"
  exit 3
fi

su - $INSTANCE_OWNER -c "db2 -v UPDATE DATABASE CONFIGURATION FOR $DB_NAME USING APPLHEAPSZ 16384"
if [ $? -ne 0 ] ; then
  echo "Error in $0: Failed to alter database"
  exit 4
fi

su - $INSTANCE_OWNER -c "db2 -v UPDATE DATABASE CONFIGURATION FOR $DB_NAME USING STMTHEAP 60000"
if [ $? -ne 0 ] ; then
  echo "Error in $0: Failed to alter database"
  exit 5
fi

su - $INSTANCE_OWNER -c "db2 -v UPDATE DATABASE CONFIGURATION FOR $DB_NAME USING APP_CTL_HEAP_SZ 8192"
if [ $? -ne 0 ] ; then
  echo "Error in $0: Failed to alter database"
  exit 6
fi

su - $INSTANCE_OWNER -c "db2 -v UPDATE DATABASE CONFIGURATION FOR $DB_NAME USING LOCKLIST 400"
if [ $? -ne 0 ] ; then
  echo "Error in $0: Failed to alter database"
  exit 7
fi

su - $INSTANCE_OWNER -c "db2 -v UPDATE DATABASE CONFIGURATION FOR $DB_NAME USING INDEXREC RESTART"
if [ $? -ne 0 ] ; then
  echo "Error in $0: Failed to alter database"
  exit 8
fi

su - $INSTANCE_OWNER -c "db2 -v UPDATE DATABASE CONFIGURATION FOR $DB_NAME USING LOGFILSIZ 1000"
if [ $? -ne 0 ] ; then
  echo "Error in $0: Failed to alter database"
  exit 9
fi

su - $INSTANCE_OWNER -c "db2 -v UPDATE DATABASE CONFIGURATION FOR $DB_NAME USING LOGPRIMARY 12"
if [ $? -ne 0 ] ; then
  echo "Error in $0: Failed to alter database"
  exit 10
fi

su - $INSTANCE_OWNER -c "db2 -v UPDATE DATABASE CONFIGURATION FOR $DB_NAME USING LOGSECOND 10"
if [ $? -ne 0 ] ; then
  echo "Error in $0: Failed to alter database"
  exit 11
fi

su - $INSTANCE_OWNER -c "db2set DB2_RR_TO_RS=yes"
if [ $? -ne 0 ] ; then
  echo "Error in $0: Failed to change DB2 setting"
  exit 12
fi

# Catalog database alias in case of local database setup.
if [ $# -eq 4 ] ; then
  su - $INSTANCE_OWNER -c "db2 -v CATALOG DATABASE $DB_NAME AS $ALIAS_NAME AT NODE $NODE_NAME"
  if [ $? -ne 0 ] ; then
    echo "Error in $0: Failed to catalog database alias"
    exit 13
  fi
fi

exit 0
